==> cuteradio_0.0.1.tar.gz: cuteradio-0.0.1/src/base/stationfilterlistmodel.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef STATIONFILTERLISTMODEL_H
#define STATIONFILTERLISTMODEL_H

#include <QSortFilterProxyModel>
#include "stationlistmodel.h"

class StationFilterListModel : public QSortFilterProxyModel
{
    Q_OBJECT
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(bool loading
               READ loading
               NOTIFY loadingChanged)
    Q_PROPERTY(QString searchQuery
               READ searchQuery
               NOTIFY searchQueryChanged)
    Q_PROPERTY(Queries::QueryType queryType
               READ queryType
               NOTIFY queryTypeChanged)
    Q_PROPERTY(QString query
               READ query
               WRITE setQuery
               NOTIFY queryChanged)
#if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
    Q_PROPERTY(QString highlightColor
               READ highlightColor
               WRITE setHighlightColor)
#endif

public:
    enum Roles {
        QueryMatchRole = StationListModel::SectionRole + 1
    };

    explicit StationFilterListModel(QObject *parent = 0);
    ~StationFilterListModel();

#if QT_VERSION >= 0x050000
    QHash<int, QByteArray> roleNames() const;
#endif

    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    Q_INVOKABLE bool setData(int row, const QVariant &value, const QByteArray &role);

    bool loading() const;

    QString searchQuery() const;

    Queries::QueryType queryType() const;

    QString query() const;

#if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
    QString highlightColor() const;
    void setHighlightColor(const QString &color);
#endif

    Station* get(const QModelIndex &index) const;
    Q_INVOKABLE Station* get(int row) const;

public slots:
    void setQuery(const QString &query);

    void searchStations(const QString &query) const;
    void showRecentlyPlayedStations() const;
    void showFavouriteStations() const;
    void showStationsByGenre(const QString &genre) const;
    void showStationsByCountry(const QString &country) const;
    void showStationsByLanguage(const QString &language) const;
    void clear();
    void reload();

private:
    QString queryMatch(QString str) const;

private slots:
    void onQueryTypeChanged(Queries::QueryType queryType);

signals:
    void countChanged(int count);
    void loadingChanged(bool loading);
    void searchQueryChanged(const QString &query);
    void queryTypeChanged(Queries::QueryType queryType);
    void queryChanged(const QString &query);
    void highlightColorChanged(const QString &color);

private:
    StationListModel *m_model;
    QString m_query;
#if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
    QString m_highlight;
#endif
    QHash<int, QByteArray> m_roleNames;
};

#endif // STATIONFILTERLISTMODEL_H

==> cuteradio_0.2.0.tar.gz: cuteradio-0.2.0/src/base/stationfilterlistmodel.h <==
/*
 * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU Lesser General Public License,
 * version 3, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
 */

#ifndef STATIONFILTERLISTMODEL_H
#define STATIONFILTERLISTMODEL_H

#include <QSortFilterProxyModel>
#include "stationlistmodel.h"

class StationFilterListModel : public QSortFilterProxyModel
{
    Q_OBJECT
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)
    Q_PROPERTY(bool loading
               READ loading
               NOTIFY loadingChanged)
    Q_PROPERTY(QString searchQuery
               READ searchQuery
               NOTIFY searchQueryChanged)
    Q_PROPERTY(Queries::QueryType queryType
               READ queryType
               NOTIFY queryTypeChanged)
    Q_PROPERTY(QString query
               READ query
               WRITE setQuery
               NOTIFY queryChanged)
#if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
    Q_PROPERTY(QString highlightColor
               READ highlightColor
               WRITE setHighlightColor)
#endif

public:
    enum Roles {
        QueryMatchRole = StationListModel::SectionRole + 1
    };

    explicit StationFilterListModel(QObject *parent = 0);
    ~StationFilterListModel();

#if QT_VERSION >= 0x050000
    QHash<int, QByteArray> roleNames() const;
#endif

    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    Q_INVOKABLE bool setData(int row, const QVariant &value, const QByteArray &role);

    bool loading() const;

    QString searchQuery() const;

    Queries::QueryType queryType() const;

    QString query() const;

#if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
    QString highlightColor() const;
    void setHighlightColor(const QString &color);
#endif

    Station* get(const QModelIndex &index) const;
    Q_INVOKABLE Station* get(int row) const;

public slots:
    void setQuery(const QString &query);

    void searchStations(const QString &query);
    void showRecentlyPlayedStations();
    void showFavouriteStations();
    void showStationsByGenre(const QString &genre);
    void showStationsByCountry(const QString &country);
    void showStationsByLanguage(const QString &language);

    void clear();
    void reload();

private:
    QString queryMatch(QString str) const;

private slots:
    void onQueryTypeChanged(Queries::QueryType queryType);

signals:
    void countChanged(int count);
    void loadingChanged(bool loading);
    void searchQueryChanged(const QString &query);
    void queryTypeChanged(Queries::QueryType type);
    void queryChanged(const QString &query);
    void highlightColorChanged(const QString &color);

private:
    StationListModel *m_model;
    QString m_query;
#if (defined QML_USER_INTERFACE) && (!defined Q_WS_MAEMO_5)
    QString m_highlight;
#endif
    QHash<int, QByteArray> m_roleNames;
};

#endif // STATIONFILTERLISTMODEL_H
